{% extends "account/base.html" %}

{% load i18n %}
{% load bootstrap %}

{% block head_title %}{% trans "Set Password" %}{% endblock %}
{% block account_nav_change_password %}active{% endblock %}

{% block account_content %}
<form method="POST" action="" class="password_set">
  {% csrf_token %}
  {{ password_set_form|bootstrap }}
  <div class="form-actions">
    <input class="btn btn-primary" type="submit" name="action" value="{% trans "Set Password" %}"/>
  </div>
</form>
{% endblock %}
