{% extends "account/base.html" %}

{% load i18n %}
{% load bootstrap %}

{% block head_title %}{% trans "Change Password" %}{% endblock %}
{% block account_nav_change_password %}active{% endblock %}

{% block account_content %}
    <form method="POST" action="" class="password_change form-horizontal">
        {% csrf_token %}
        {{ password_change_form|bootstrap_horizontal }}
        <div class="form-actions">
          <button class="btn btn-primary" type="submit" name="action">{% trans "Change Password" %}</button>
        </div>
    </form>
{% endblock %}
