{% extends "account/base.html" %}

{% load url from future %}
{% load i18n %}
{% load bootstrap %}

{% block head_title %}{% trans "Change Password" %}{% endblock %}

{% block content %}
<h1>{% if token_fail %}{% trans "Bad Token" %}{% else %}{% trans "Change Password" %}{% endif %}</h1>
    
{% if token_fail %}
{% url 'account_reset_password' as passwd_reset_url %}
<p>{% blocktrans %}The password reset link was invalid, possibly because it has already been used.  Please request a <a href="{{ passwd_reset_url }}">new password reset</a>.{% endblocktrans %}</p>

{% else %}
{% if form %}
<form method="POST" action="" class="uniForm">
  {% csrf_token %}
  {{form|bootstrap}}
  <div class="form-actions">
    <button class="btn btn-primary" type="submit">{% trans "Change Password" %}</button>
  </div>
</form>
{% else %}
<p>{% trans 'Your password is now changed.' %}</p>
{% endif %}
{% endif %}

{% endblock %}
