{% extends "base.html" %}

{% load url from future %}
{% load i18n %}

{% block content %}

<h1>{% trans 'My Account' %}</h1>

<ul class="nav nav-tabs">
  <li class="{% block account_nav_email %}{% endblock %}">
    <a href="{% url 'account_email' %}">{% trans 'E-mail Addresses' %}</a>
  </li>
  <li class="{% block account_nav_change_password %}{% endblock %}">
    <a href="{% url 'account_change_password' %}">{% trans 'Change Password' %}</a>
  </li>
  {% url 'socialaccount_connections' as connections_url %}
  {% if connections_url %}
  <li class="{% block account_nav_socialaccount_connections %}{% endblock %}">
    <a href="{{ connections_url}}">{% trans 'Connected Accounts' %}</a>
  </li>
  {% endif %}
</ul>
{% block account_content %}
{% endblock %}

{% endblock %}

