{% extends "account/base.html" %}

{% load bootstrap %}
{% load i18n %}

{% block head_title %}{% trans "Sign Up" %}{% endblock %}

{% block content %}

<h1>{% trans "Sign Up" %}</h1>

<p>{% blocktrans %}Already have an account? Then please <a href="{{ login_url }}">log in</a>.{% endblocktrans %}</p>

{% block help_text %}
{% endblock help_text %}

<form id="signup_form" class="form-horizontal" method="post" action="{% url 'account_signup' %}">
  {% csrf_token %}
  {{ form|bootstrap_horizontal }}
  {% if redirect_field_value %}
  <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}" />
  {% endif %}
  <div class="form-actions">
  <button class="btn btn-primary" type="submit">{% trans "Sign Up" %}</button>
  </div>
</form>

{% endblock %}
